===========================
Changes in version 2016.1.0
===========================

FFC 2016.1.0 was released on 2016-06-23.

- Add function get_ufc_include to get path to ufc.h
- Merge UFLACS into FFC
- Generalize ufc interface to non-affine parameterized coordinates
- Add ufc::coordinate_mapping class
- Make ufc interface depend on C++11 features requiring gcc version >= 4.8
- Add function ufc_signature() to the form compiler interface
- Add function git_commit_hash()
